==> hs-cpphs-1.9.tbz: lib/cpphs-1.9/register.sh <==
#!/bin/sh

echo 'name: cpphs
version: 1.9
license: LGPL
copyright: 2004-2009, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@cs.york.ac.uk>
stability:
homepage: http://haskell.org/cpphs/
package-url:
description: Cpphs is a re-implementation of the C pre-processor that is both
             more compatible with Haskell, and itself written in Haskell so
             that it can be distributed with compilers.
             .
             This version of the C pre-processor is pretty-much
             feature-complete and compatible with traditional (K&R)
             pre-processors.  Additional features include: a plain-text mode;
             an option to unlit literate code files; and an option to turn
             off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@cs.york.ac.uk>
exposed: True
exposed-modules: Language.Preprocessor.Cpphs
                 Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
                Text.ParserCombinators.HuttonMeijer
import-dirs: /usr/local/lib/cpphs-1.9/ghc-6.10.4
library-dirs: /usr/local/lib/cpphs-1.9/ghc-6.10.4
hs-libraries: HScpphs-1.9
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.1.0.0 haskell98-1.0.1.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cpphs-1.9/html/cpphs.haddock
haddock-html: /usr/local/share/doc/cpphs-1.9/html' | /usr/local/bin/ghc-pkg update -

==> hs-cpphs-1.11.tbz: lib/cpphs-1.11/register.sh <==
#!/bin/sh

echo 'name: cpphs
version: 1.11
license: LGPL
copyright: 2004-2010, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@cs.york.ac.uk>
stability:
homepage: http://haskell.org/cpphs/
package-url:
description: Cpphs is a re-implementation of the C pre-processor that is both
             more compatible with Haskell, and itself written in Haskell so
             that it can be distributed with compilers.
             .
             This version of the C pre-processor is pretty-much
             feature-complete and compatible with traditional (K&R)
             pre-processors.  Additional features include: a plain-text mode;
             an option to unlit literate code files; and an option to turn
             off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@cs.york.ac.uk>
exposed: True
exposed-modules: Language.Preprocessor.Cpphs
                 Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
                Text.ParserCombinators.HuttonMeijer
import-dirs: /usr/local/lib/cpphs-1.11/ghc-6.10.4
library-dirs: /usr/local/lib/cpphs-1.11/ghc-6.10.4 /usr/local/lib
hs-libraries: HScpphs-1.11
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.1.0.0 haskell98-1.0.1.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cpphs-1.11/html/cpphs.haddock
haddock-html: /usr/local/share/doc/cpphs-1.11/html' | /usr/local/bin/ghc-pkg update -
